PALM-meteo: palmmeteo.plugins.Plugin Class Reference

PALM-meteo

Public Member Functions | List of all members
palmmeteo.plugins.Plugin Class Reference
Inheritance diagram for palmmeteo.plugins.Plugin:
[legend]
Collaboration diagram for palmmeteo.plugins.Plugin:
[legend]

## Public Member Functions
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)

## Detailed Description

    Base class for plugins

    The objects are not persistent across multiple runs, so their members (if
    any) should be created by the constructor and any stage should not expect
    members to be created by the preceding stages. Use rt to store persistent
    data.

## Member Function Documentation

## ◆ check_config()

def palmmeteo.plugins.Plugin.check_config | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

    (Load and) validate plugin-related configuration.

    Any plugin can optinally implement the check_config method for
    validating configuration. It is not required, so the method is not
    abstract.

Reimplemented in palmmeteo_stdplugins.aladin.AladinPlugin, palmmeteo_stdplugins.icon.IconPlugin, palmmeteo_stdplugins.winddamp.WindDampPlugin, palmmeteo_stdplugins.wrf.WRFPlugin, and palmmeteo_stdplugins.wrf.WRFRadPlugin.

The documentation for this class was generated from the following file:

- palmmeteo/plugins.py